==> camel-core-model-3.18.1-sources.jar: org/apache/camel/model/loadbalancer/RoundRobinLoadBalancerDefinition.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.model.loadbalancer;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlRootElement;

import org.apache.camel.model.LoadBalancerDefinition;
import org.apache.camel.spi.Metadata;

/**
 * The destination endpoints are selected in a round-robin fashion. This is a well known and classic policy, which
 * spreads the load evenly.
 */
@Metadata(label = "eip,routing")
@XmlRootElement(name = "roundRobin")
@XmlAccessorType(XmlAccessType.FIELD)
public class RoundRobinLoadBalancerDefinition extends LoadBalancerDefinition {

    public RoundRobinLoadBalancerDefinition() {
    }

    @Override
    public String toString() {
        return "RoundRobinLoadBalancer";
    }

}

==> camel-core-model-4.6.0-sources.jar: org/apache/camel/model/loadbalancer/RoundRobinLoadBalancerDefinition.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.model.loadbalancer;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlRootElement;

import org.apache.camel.model.LoadBalancerDefinition;
import org.apache.camel.spi.Metadata;

/**
 * The destination endpoints are selected in a round-robin fashion. This is a well-known and classic policy, which
 * spreads the load evenly.
 */
@Metadata(label = "eip,routing")
@XmlRootElement(name = "roundRobin")
@XmlAccessorType(XmlAccessType.FIELD)
public class RoundRobinLoadBalancerDefinition extends LoadBalancerDefinition {

    public RoundRobinLoadBalancerDefinition() {
    }

    @Override
    public String toString() {
        return "RoundRobinLoadBalancer";
    }

}
